@@ -1,5 +1,5 @@
 node2SPDF <-
-function(XML, crs=CRS("+init=epsg:4326")){
+function(XML, crs=CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +towgs84=0,0,0")){
   stopifnot("XMLNodeSet" %in% class(XML)| "list" %in% class(XML))
   eltype<-attr(XML, "element")
   if(length(XML)==0)
